from requests import get

api_url = "https://exchange.xforce.ibmcloud.com/api" 

def activity(activity_id, auth): 
    data = loads(eval(get(f'{api_url}/threat_activities/{activity_id}',
               headers={ 'Authorization': f'Basic {auth}' }).text))
    data['url'] = f'https://exchange.xforce.ibmcloud.com/threats/{activity_id}'
    return data

def malware(malware_id, auth): 
    data = loads(eval(get(f'{api_url}/malware_analysis/{malware_id}',
               headers={ 'Authorization': f'Basic {auth}' }).text))
    data['url'] = f'https://exchange.xforce.ibmcloud.com/malware_analysis/{malware_id}'
    return data

def group(groups_id, auth): 
    data = loads(eval(get(f'{api_url}/threat_groups/{groups_id}',
               headers={ 'Authorization': f'Basic {auth}' }).text))
    data['url'] = f'https://exchange.xforce.ibmcloud.com/threat-group/{groups_id}'
    return data

def collector(collector_id, auth): 
    data = loads(eval(get(f'{api_url}/casefiles/{collector_id}',
               headers={ 'Authorization': f'Basic {auth}' }).text))
    data['url'] = f'https://exchange.xforce.ibmcloud.com/collector/{collector_id}'
    return data

def industry(industries_id, auth): 
    data = loads(eval(get(f'{api_url}/industries/{industries_id}',
               headers={ 'Authorization': f'Basic {auth}' }).text))
    data['url'] = f'https://exchange.xforce.ibmcloud.com/industries/{industries_id}'
    return data



#!/usr/bin/python3 
from requests import get
import XForce.details
from json import loads

api_url = "https://exchange.xforce.ibmcloud.com/api" 

# Sources of search
def threat_activities(term, auth):
    return get(f"{api_url}/threat_activities/search/{term}",
               headers={ 'Authorization': f'Basic {auth}' }).text

def malware_analysis(term, auth):
    return get(f"{api_url}/malware_analysis/search/{term}",
               headers={ 'Authorization': f'Basic {auth}' }).text

def threat_groups(term, auth):
    return get(f"{api_url}/threat_groups/search/{term}",
               headers={ 'Authorization': f'Basic {auth}' }).text

def collector(term, auth):
    return get(f"{api_url}/casefiles/public/fulltext?q={term}",
               headers={ 'Authorization': f'Basic {auth}' }).text

def industries(term, auth):
    return get(f"{api_url}/industries/search/{term}",
               headers={ 'Authorization': f'Basic {auth}' }).text

def all(term, auth):
    big_list = []
    big_list = threat_activities(term, auth)["rows"] + malware_analysis(term, auth)["rows"] + threat_groups(term, auth)["rows"] + collector(term, auth)["casefiles"] + industries(term, auth)["rows"]
    return big_list




import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='XForce',
    version=0.6,
    author="Julio Lira",
    author_email="jul10l1r4@disroot.org",
    description="IBM Security utilitary library in python. Search and query all sources: threat_activities and groups, malware_analysis, industries ",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Jul10l1r4/x-force",
    packages=["XForce", "XForce", "XForce.details"],
    license="GPLv3",
    keywords="threat intelligence security ibm xforce x-force blueteam search query api exchange otx cti oct",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
        "Topic :: Internet",
        "Topic :: Security",
        ],
    )

